mod xapcm;

use super::Arguments;
use super::raw_audio::{I16Samples, Settings};
use std::io::Write;
use symphonia::core::audio::Layout;
use tool_helper::Error;

const HIGH_FREQUENCY:u32      = 37_800;
const  LOW_FREQUENCY:u32      = 18_900;

pub fn audio_conversion_settings(arguments: &Arguments) -> Settings {
    let frequency = match arguments.frequency {
        super::Frequency::High => HIGH_FREQUENCY,
        super::Frequency::Low  => LOW_FREQUENCY,
    };
    let layout    = match arguments.orality {
        super::Orality::Stereo => Layout::Stereo,
        super::Orality::Mono   => Layout::Mono,
    };

    Settings::new(frequency, layout)
}

pub fn encode(input: I16Samples, output: &mut dyn Write, arguments: &Arguments) -> Result<(), Error> {
    let mut encoder      = xapcm::Encoder::new(&input, arguments.clone());
    let mut sector_count = 0;

    while let Some(xa_sector) = encoder.encode_next_xa_sector()? {
        output.write(&xa_sector)?;

        sector_count += 1;
        print!("\rSector: {} written", sector_count);
    }
    println!();
    //Err(Error::not_implemented("XA conversion"))
    Ok(())
}